/*
 * Copyright 2024 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include "baiduengine.h"
#include "baiduspeechengine.h"
#include "baidunlpengine.h"
#include "baiduvisionengine.h"

std::string BaiduAiEngine::engineName() const
{
    return "baidu";
}

std::vector<ai_engine::lm::AiCapability> BaiduAiEngine::aiCapabilities() const {
    return { ai_engine::lm::AiCapability::Nlp, ai_engine::lm::AiCapability::Speech, ai_engine::lm::AiCapability::Vision };
}

std::unique_ptr<ai_engine::lm::speech::AbstractSpeechEngine> BaiduAiEngine::createSpeechEngine() {
    return std::make_unique<BaiduSpeechEngine>();
}

std::unique_ptr<ai_engine::lm::nlp::AbstractNlpEngine> BaiduAiEngine::createNlpEngine() {
    return std::make_unique<BaiduNlpEngine>();
}

std::unique_ptr<ai_engine::lm::vision::AbstractVisionEngine> BaiduAiEngine::createVisionEngine() {
    return std::make_unique<BaiduVisionEngine>();
}

AI_LARGE_MODEL_ENGINE_FACTORY(BaiduAiEngine);
