/*
 * Copyright 2024 KylinSoft Co., Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
 * details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program. If not, see <https://www.gnu.org/licenses/>.
 */

#include "baiduspeechengine.h"

BaiduSpeechEngine::BaiduSpeechEngine() : d(new BaiduSpeechEnginePrivate()) {}

BaiduSpeechEngine::~BaiduSpeechEngine() { delete d; }

std::string BaiduSpeechEngine::backendName() { return d->backendName(); }

void BaiduSpeechEngine::setAppId(const std::string &appId) {
    d->setAppId(appId);
}

void BaiduSpeechEngine::setApiKey(const std::string &apiKey) {
    d->setApiKey(apiKey);
}

void BaiduSpeechEngine::setSecretKey(const std::string &secretKey) {
    d->setSecretKey(secretKey);
}

void BaiduSpeechEngine::setRecognizingCallback(
    ai_engine::lm::speech::RecognitionResultCallback callback) {
    d->setRecognizingCallback(callback);
}

void BaiduSpeechEngine::setRecognizedCallback(
    ai_engine::lm::speech::RecognitionResultCallback callback) {
    d->setRecognizedCallback(callback);
}

void BaiduSpeechEngine::setSynthesizingCallback(
    ai_engine::lm::speech::SynthesisResultCallback callback) {
    d->setSynthesizingCallback(callback);
}

void BaiduSpeechEngine::setSynthesizedCallback(
    ai_engine::lm::speech::FinishedCallback callback) {
    d->setSynthesizedCallback(callback);
}

ai_engine::ErrorCode BaiduSpeechEngine::initContinuousRecognitionModule() {
    return d->initContinuousRecognitionModule();
}

ai_engine::ErrorCode
BaiduSpeechEngine::startContinuousRecognition(const std::string &params) {
    return d->startContinuousRecognition(params);
}

ai_engine::ErrorCode BaiduSpeechEngine::writeContinuousRecognitionAudioData(
    const std::vector<char> &audioData) {
    return d->writeContinuousRecognitionAudioData(audioData);
}

ai_engine::ErrorCode BaiduSpeechEngine::stopContinuousRecognition() {
    return d->stopContinuousRecognition();
}

ai_engine::ErrorCode BaiduSpeechEngine::destroyContinuousRecognitionModule() {
    return d->destroyContinuousRecognitionModule();
}

ai_engine::ErrorCode BaiduSpeechEngine::initRecognizeOnceModule() {
    return d->initRecognizeOnceModule();
}

ai_engine::ErrorCode
BaiduSpeechEngine::recognizeOnce(const std::string &params,
                                 const std::vector<char> &audioData) {
    return d->recognizeOnce(params, audioData);
}

ai_engine::ErrorCode BaiduSpeechEngine::destroyRecognizeOnceModule() {
    return d->destroyRecognizeOnceModule();
}

ai_engine::ErrorCode BaiduSpeechEngine::initContinuousSynthesisModule() {
    return d->initContinuousSynthesisModule();
}

ai_engine::ErrorCode
BaiduSpeechEngine::startContinuousSynthesis(const std::string &params) {
    return d->startContinuousSynthesis(params);
}

ai_engine::ErrorCode
BaiduSpeechEngine::writeContinuousSynthesisText(const std::string &text) {
    return d->writeContinuousSynthesisText(text);
}

ai_engine::ErrorCode BaiduSpeechEngine::stopContinuousSynthesis() {
    return d->stopContinuousSynthesis();
}

ai_engine::ErrorCode BaiduSpeechEngine::destroyContinuousSynthesisModule() {
    return d->destroyContinuousSynthesisModule();
}

ai_engine::ErrorCode BaiduSpeechEngine::initSynthesizeOnceModule() {
    return d->initSynthesizeOnceModule();
}

ai_engine::ErrorCode
BaiduSpeechEngine::synthesizeOnce(const std::string &params,
                                  const std::string &text) {
    return d->synthesizeOnce(params, text);
}

ai_engine::ErrorCode BaiduSpeechEngine::destroySynthesizeOnceModule() {
    return d->destroySynthesizeOnceModule();
}